<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="xml" indent="yes"/>

<xsl:template match="/certification-test">
<package-summary version="0.01">
  <runs>
    <xsl:call-template name="test-results">
      <xsl:with-param name="run-counter">
        <xsl:value-of select="@number-of-runs"/>
      </xsl:with-param>
    </xsl:call-template>
  </runs>
</package-summary>
</xsl:template>

<xsl:template name="test-results">
  <xsl:param name="run-counter"/>
  <xsl:if test="$run-counter &gt; 1">
    <xsl:call-template name="test-results">
      <xsl:with-param name="run-counter">
        <xsl:value-of select="$run-counter - 1"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:if>

  <run number="{$run-counter}"> 
  <xsl:for-each select="device-class">
    <xsl:variable name="device-class-position" select="position()"/>
    <xsl:for-each select="test">
      <xsl:variable name="test-position" select="position()"/>
      <xsl:variable name="test-name" select="@name"/>
      <xsl:variable name="udi" select="@udi"/>
      <xsl:for-each select="run">
        <xsl:variable name="run-position" select="position()"/>
        <xsl:if test="@number = $run-counter">
          <xsl:variable name="short-udi" select="substring-after($udi,'Hal/devices/')"/>
          <xsl:variable name="return-value" select="@return-value"/>
          <xsl:variable name="summary">
              <xsl:value-of select="summary"/>
          </xsl:variable>
          <xsl:variable name="xpath">
            <xsl:for-each select="ancestor-or-self::*">
              <xsl:text>/</xsl:text>
              <xsl:value-of select="name()"/>
              <xsl:choose>
                <xsl:when test='name()="device-class"'>
                  <xsl:text>[</xsl:text>
                  <xsl:value-of select="$device-class-position"/>
                  <xsl:text>]</xsl:text>
                </xsl:when>
                <xsl:when test='name()="test"'>
                  <xsl:text>[</xsl:text>
                  <xsl:value-of select="$test-position"/>
                  <xsl:text>]</xsl:text>
                </xsl:when>
                <xsl:when test='name()="run"'>
                  <xsl:text>[</xsl:text>
                  <xsl:value-of select="$run-position"/>
                  <xsl:text>]</xsl:text>
                </xsl:when>
              </xsl:choose>
            </xsl:for-each>
          </xsl:variable> 
          <test name="{$test-name}"
                udi="{$short-udi}"
                return-value="{$return-value}"
                summary="{$summary}"
                xpath="{$xpath}"/>
        </xsl:if>
      </xsl:for-each>
    </xsl:for-each>
  </xsl:for-each>
  </run>

</xsl:template>
</xsl:stylesheet>
